@@ -11,7 +11,7 @@ class AskUntilFileExists(Environment):
 	
 	def __init__(self,path): self._path    = path
 		
-	def equal(self,x): return self._path==x._path and self._message==x._message
+	def equal(self,x): return self._path==x._path
 	def str(self): return self._path+' exists'
 	
 	def compatible(self,x): return Reason()
@@ -139,5 +139,3 @@ class DirectoryEmpty(Environment):
 		return reason
 	def retract(self): return Reason()
 
-
-			
