@@ -37,7 +37,6 @@ def mirrorCreate(clist,mirrorfile):
 	
 _shown     = {}
 _messageDB = {}
-#_prepend = {}
 
 class MirrorCache(Cache.Cache):
 	def __init__(self,cache,mirror=''):
@@ -67,7 +66,9 @@ class MirrorCache(Cache.Cache):
 		
 		self._top      = 1
 		
-	def str(self): return self.UCL
+	def str(self): 
+		if hasattr(self,'_name'): return self._name
+		else:                     return self.UCL
 		
 	def display(self,indent=0):
 		upd = self._top and (displayMode('up') or verbo('up'))
@@ -136,7 +137,7 @@ class MirrorCache(Cache.Cache):
 			if r.ok():
 				if 'lock' in files:
 					r = self._access.lockCheck()
-					if r.ok(): r = Reason("Cache ["+self.str()+"] is locked.")
+					if not r.ok(): r = Reason("Cache ["+self.str()+"] is being updated at the moment.  Try again later...")
 				elif 'o..basemirror..o' in files:
 					self._leaf   = MirrorBaseCache.MirrorBaseCache(self.UCL)
 				if r.ok() and 'o..mirror..o' in files:
@@ -163,7 +164,6 @@ class MirrorCache(Cache.Cache):
 									tname = name. replace(':','_')
 									tname = tname.replace('/',ESC)
 									c = MirrorCache(os.path.join(self.UCL,tname))
-#									c = MirrorCache(os.path.join(self.UCL,name.replace('/',ESC)))
 									c._name = name
 									c._top  = 0
 									self._cache.append(c)
@@ -171,8 +171,8 @@ class MirrorCache(Cache.Cache):
 							self._init = 1
 						else:
 							r = Reason("["+self.str()+"] is unreadable.")
-				else:
-					r = Reason("["+self.str()+"] is not a mirror cache.")
+#				else:
+#					r = Reason("["+self.str()+"] is not available at this time.")
 #		if not r.ok() and not (switch('lc') or switch('l')):
 #			message = `r`
 #			if not _messageDB.has_key(message):
@@ -208,10 +208,13 @@ class MirrorCache(Cache.Cache):
 		return r
 		
 	def getUpdates(self):
+		r = self.init().require()
 		updates = []
 		if self.leaf(): updates.extend(self._leaf.getUpdates())
 		else:
-			for c in self._cache: updates.extend(c.getUpdates())
+			for c in self._cache: 
+				x = c.getUpdates()
+				updates.extend(c.getUpdates())
 		return updates
 	def getNewCaches(self):
 		newcaches = []
@@ -240,14 +243,14 @@ class MirrorCache(Cache.Cache):
 	def create(self,name=''):
 		r = Reason("Can't create ["+self.str()+"] from a remote location.",self._location=='')
 		if r.ok(): r = Reason("No cache specified for ["+self.str()+"].",self._mirror=='')
-		if r.ok(): r = Reason("["+self._location+"] already exists.",os.path.exists(self._location))
+#		if r.ok(): r = Reason("File ["+self._location+"] already exists.",os.path.exists(self._location))
 
 		if r.ok():
 			mirror = UniversalCache.UniversalCache(self._mirror)._cache
 			if mirror.type=='list':
 				self._createTime = time.time()
 				self._checkTime  = copy.deepcopy(self._createTime)
-				r = Execution.execute('mkdir '+self._location)
+				r = Execution.execute('rm -r -f '+self._location+'; mkdir '+self._location)
 				if r.ok(): r = self.readme()
 				if r.ok():
 					r = mirror.init()
@@ -332,13 +335,11 @@ class MirrorCache(Cache.Cache):
 				mirror = UniversalCache.UniversalCache(self._mirror)._cache
 				if mirror.type=='list':
 					mirror.init()
-					self._newcache = UniversalCache.CacheList(self.UCL)
-					self._newcache.init()
+					self._newcache = UniversalCache.CacheList('')
 					for c in mirror:
 						loc = c._name.replace(':','_')
 						loc = loc.    replace('/',ESC)
 						loc = os.path.join(self._location,loc)
-#						loc = os.path.join(self._location,c._name.replace('/',ESC))
 						mir = MirrorCache(loc,c.UCL)
 						mir._name = c._name[:]
 						self._newcache.append(mir)
@@ -402,7 +403,7 @@ class MirrorCache(Cache.Cache):
 					for c in self._cache: self._names.append(c._name)
 					self._updateTime = time.time()
 					self._newcache = None
-		if not self.leaf():
+		if r.ok() and not self.leaf():
 			for c in self._cache:
 				r = c.newcaches()
 				if not r.ok(): break
