@@ -25,6 +25,12 @@ def equivCachesSpec(specCache,cDB,c):
 			if cSnap and Registry.registry.equiv(cMirror,specMirror) and cTime==specTime:
 				eq = 1
 	return eq
+	
+def clred(cl):
+	cs = []
+	for c in cl:
+		if not tail(c,'.caches'): cs.append(c)
+	return cs
 
 def satisfiedByCaches(caches,db,pcaches):
 	ok = 1
@@ -115,9 +121,10 @@ class Spec(PreOrder,HtmlOut):
 		self.mayBeModifiedBy = ['']
 		self._mirrors = {}
 			
-	def _id (self): return `self.caches,self.name,self.subdirectory,self.file`
+#	def _id (self): return `self.caches,self.name,self.subdirectory,self.file`
+	def _id (self): return `clred(self.caches),self.name,self.subdirectory,self.file`
 	def __eq__(self,x):  return self.name==x.name and self.file==x.file and \
-			self.subdirectory==x.subdirectory and self.caches==x.caches and self.location==x.location
+			self.subdirectory==x.subdirectory and clred(self.caches)==clred(x.caches) and self.location==x.location
 			
 	def strip(self,c):
 		spec = copy.deepcopy(self)
@@ -149,8 +156,8 @@ class Spec(PreOrder,HtmlOut):
 	def satisfiedBy (self,p): return self.satisfiedByR(p).ok()
 	def satisfiedByR(self,p):
 		r = Reason()
-		specCaches = self.caches[:]
-		pCaches    = p._spec.caches[:]
+		specCaches = clred(self.caches[:])
+		pCaches    = clred(p._spec.caches[:])
 		if hasattr(p._spec,'_mirrors'): m = p._spec._mirrors
 		else:                           m = {}
 		if satisfiedByCaches(specCaches,m,pCaches):
@@ -172,7 +179,8 @@ class Spec(PreOrder,HtmlOut):
 	def __repr__(self): return 'spec: '+self.str()
 	def str(self): 
 		s = ''
-		for cache in self.caches:  s = s + cache + ':'
+#		for cache in self.caches:  s = s + cache + ':'
+		for cache in self.caches:  s = s + Registry.registry.short(cache) + ':'
 		if self.subdirectory !='': s = s + self.subdirectory + '/'
 		s = s + self.name
 		if self.guard        !='': s = s + ' | '+self.guard
@@ -285,6 +293,31 @@ class Package(Environment,Update,Verify):
 		self._environ     == p._environ   and \
 		self._source      == p._source 
 	def upEqual(self,es1,es2):
+		if len(es1)==len(es2):
+			eq = 1
+			for i in range(len(es1)):
+				e1,e2 = es1[i],es2[i]
+				if e1.type=='pacman source code' and e2.type=='pacman source code':
+					pass
+				else:
+					if e1.type=='lazy package' and e2.type=='lazy package':
+						eq = e1._spec.equalUp(e2._spec)
+					elif e1.type=='OR' and e2.type=='OR':
+						eq = self.upEqual(e1,e2)
+					elif e1.type=='AND' and e2.type=='AND':
+						eq = self.upEqual(e1,e2)
+					else:
+						eq = e1==e2
+				if not eq: 
+					if debug('up'): 
+						print self
+						print e1
+						print e2
+					break
+		else:
+			eq = 0
+		return eq
+	def upEqualOLD(self,es1,es2):
 		if len(es1)==len(es2):
 			eq = 1
 			for i in range(len(es1)):
@@ -641,7 +674,11 @@ class Package(Environment,Update,Verify):
 							self._source     = copy.deepcopy(self._update)
 							self._sourceCode = self._updateSourceCode
 							self._update = OR()
-							if upd: r = self.satisfy()
+							if upd: 
+								r = self.satisfy()
+								c = UniversalCache.UniversalCache('home')
+								c.put(self)
+								r = allReason(self._modifiers,lambda spec: LazyPackage(spec).satisfy())
 					else:
 						verbo.log('up',"Can't uninstall ["+self._spec.name+"].  Not updated...")
 				else:
@@ -654,11 +691,13 @@ class Package(Environment,Update,Verify):
 			if self.updateWaiting():
 				if not switch('single'): r = self._environ.update()
 				if r.ok(): r = self.updateSelf()
+#
+#-- ??
+#			rr,pp = UniversalCache.UniversalCache('home').get(self._spec)
+#			if rr.ok() and inst and not pp.lastsat:
+#				self = pp
+#				r = self.satisfy()
 
-			rr,pp = UniversalCache.UniversalCache('home').get(self._spec)
-			if rr.ok() and inst and not pp.lastsat:
-				self = pp
-				r = self.satisfy()
 #			if self.updateWaiting(): r = self.updateSelf()
 #			if r.ok(): r = self._environ.update()
 		return self.reasonFixup(r,'updated')
@@ -732,6 +771,15 @@ class LazyPackage(Package):
 			r = Reason()
 			p = Package()
 		return r,p
+	def lazyApplyZ(self,f=lambda p: Reason()):
+		r,p = self.lazyApplyU(f)
+		if not p==Package():
+			c = UniversalCache.UniversalCache('home')
+			r,p2 = c.get(p._spec)
+			if not (r.ok() and p2.satisfied()):
+				r2 = c.put(p)
+				if r.ok(): r = r2
+		return r
 	def lazyApplyM(self,f=lambda p: Reason()):
 		r,p = self.lazyApplyU(f)
 		if not p==Package(): 
@@ -834,7 +882,7 @@ class LazyPackage(Package):
 	def updateCheck  (self): return self.check (_updateCheck,  lambda: self.lazyApplyM(lambda x: x.updateCheck   ())    )
 	def updateRemove (self): return self.check (_updateRemove, lambda: self.lazyApplyM(lambda x: x.updateRemove  ())    )
 	def updateSelf   (self): return self.check (_updateSelf,   lambda: self.lazyApplyM(lambda x: x.updateSelf    ())    )
-	def update       (self): return self.check (_update,       lambda: self.lazyApplyM(lambda x: x.update        ())    )
+	def update       (self): return self.check (_update,       lambda: self.lazyApplyZ(lambda x: x.update        ())    )
 	def updateWaiting(self): return self.lazyApplyU(lambda x: x.updateWaiting ())[0]
 
 #-- Setup
