@@ -3,12 +3,13 @@
 #
 from Base         import *
 from Environment  import *
+import FileMode
 import os
 
 def getInpaths(path,pre='',expaths=[]):
 	if os.path.isfile(os.path.join(path,pre)):
 		try:
-			if FileMode(os.path.join(path,pre)).ownerExecute():
+			if FileMode.FileMode(os.path.join(path,pre)).ownerExecute():
 				expaths.append(os.path.join(pre))
 		except OSError:
 			print "Can't read ["+os.path.join(path,pre)+"].  Skipping..."
@@ -32,8 +33,10 @@ class Path(Environment):
 		self.env    = env
 		self.file   = filename
 		self.option = option
+		if   contains(option,'front'): self.option = 'front'
+		elif contains(option,'back' ): self.option = 'back'
 		self._force = force
-#		self._force = 1
+		if contains(option,'nocheck') or contains(option,'no-check') or contains(option,'overwrite'): self._force=1
 
 	def equal(self,x): return self.env==x.env and self.value==x.value
 	def str(self): 
@@ -43,7 +46,7 @@ class Path(Environment):
 		r = AllReason()
 		newpaths = []
 		getInpaths(self.value,'',newpaths)
-		if self._dirs.has_key(self.env):
+		if not self._force and self._dirs.has_key(self.env):
 			for d in self._dirs[self.env]:
 				verbo.log('path','Checking if ['+`self`+'] clashes with ['+d+']...')
 				if not fullpath(d)==fullpath(self.value):
@@ -78,15 +81,17 @@ class Path(Environment):
 			if r.ok():
 				if not self._dirs.has_key(self.env): self._dirs[self.env] = []
 				self._dirs[self.env].append(self.value)
-				
+
 				if os.environ.has_key(self.env):
 					verbo.log('path','About to add ['+self.value+'] to ['+self.env+']...')
 					r = ask.re('path','OK to add ['+self.value+'] to ['+self.env+']?')
 					if r.ok():
 						v0 = os.environ[self.env]
-						if   self.option=='front': os.environ[self.env] = self.value + os.pathsep + v0
-						elif self.option== 'back': os.environ[self.env] =         v0 + os.pathsep + self.value
-						else: abort('Unknown option in Paths ['+self.option+"] must be 'front' or 'back'.")
+						if contains(self.option,'back'): os.environ[self.env] =         v0 + os.pathsep + self.value
+						else:                            os.environ[self.env] = self.value + os.pathsep + v0
+#						if   self.option=='front': os.environ[self.env] = self.value + os.pathsep + v0
+#						elif self.option== 'back': os.environ[self.env] =         v0 + os.pathsep + self.value
+#						else: abort('Unknown option in Paths ['+self.option+"] must be 'front' or 'back'.")
 						verbo.log('path',self.env+'='+os.environ[self.env]+'...')
 				else:
 					verbo.log('path','About to set ['+self.env+'] to ['+self.value+']...')
@@ -95,8 +100,9 @@ class Path(Environment):
 						os.environ[self.env] = self.value
 						verbo.log('path',self.env+'='+os.environ[self.env]+'...')
 		else:
-			verbo.log('path',"["+self.value+"] is not a directory.  Can't add to path variable ["+self.env+"].")
-			if not self._force: r = Reason("["+self.value+"] is not a directory.  Can't add to path variable ["+self.env+"].")
+			if not self._force:
+				verbo.log('path',"["+self.value+"] is not a directory.  Can't add to path variable ["+self.env+"].")
+				r = Reason("["+self.value+"] is not a directory.  Can't add to path variable ["+self.env+"].")
 		return r
 		
 	def retract(self):
@@ -128,24 +134,25 @@ class Path(Environment):
 						verbo.log('path',self.env+'='+os.environ[self.env]+'...')
 		return r
 
-	def shellOut(self,csh,sh,py,pl):
+	def shellOut(self,csh,sh,py,pl,ksh):
 		if self.acquired:
 			csh.write('if ($?'+self.env+') then \n')
-			if   self.option=='front':
-				csh.write('        setenv '+self.env+' '+self.value+os.pathsep+'${'+self.env+'}\n')
-			elif self.option=='back':
+			if contains(self.option,'back'):
 				csh.write('        setenv '+self.env+' '+'${'+self.env+'}'+os.pathsep+self.value+'\n')
 			else:
-				abort('Unknown option ['+self.option+'] in Paths.')
+				csh.write('        setenv '+self.env+' '+self.value+os.pathsep+'${'+self.env+'}\n')
 			csh.write('else\n')
 			csh.write('        setenv '+self.env+' '+self.value+'\n')
 			csh.write('endif\n')
 		
-			if   self.option=='front': sh.write(self.env+'="'+self.value+os.pathsep+'$'+self.env+'"\n')
-			elif self.option== 'back': sh.write(self.env+'="'+'$'+self.env+os.pathsep+self.value+'"\n')
-			else:   abort('Unknown option ['+self.option+'] in Paths.')
+			if   contains(self.option,'back' ): sh.write(self.env+'="'+'$'+self.env+os.pathsep+self.value+'"\n')
+			else:                               sh.write(self.env+'="'+self.value+os.pathsep+'$'+self.env+'"\n')
 			sh.write('export '+self.env+'\n')
 		
+			if   contains(self.option,'back' ): ksh.write(self.env+'="'+'$'+self.env+os.pathsep+self.value+'"\n')
+			else:                               ksh.write(self.env+'="'+self.value+os.pathsep+'$'+self.env+'"\n')
+			ksh.write('export '+self.env+'\n')
+		
 			py.write('if os.environ.has_key("'+self.env+'"): os.environ["'+self.env+'"] = "'+os.path.expandvars(self.value)+os.pathsep+'"+'+'os.environ["'+self.env+'"]\n')
 			py.write('else: os.environ["'+self.env+'"] = "'+os.path.expandvars(self.value)+'"\n')
 			
