@@ -19,11 +19,9 @@ class RPM(Environment):
 	
 #-- Satisfiable
 	def satisfied(self): 
-		if fileInPath('rpm').ok():
-			if rpm_installed(self.rpmfile): return Reason()
-			else: return Reason('RPM ['+self.rpmfile+'] has not been installed.')
-		else:
-			return Reason('rpm is not available or is not in your $PATH.')
+		r = Reason('rpm ['+self.rpmfile+'] is not installed.',not rpm_installed(self.rpmfile))
+		self.satset(r.ok())
+		return r
 			
 	def satisfiable(self):
 		reason = Reason()
@@ -40,5 +38,5 @@ class RPM(Environment):
 				reason = execute('rpm -U --force '+self.rpmfile)
 		return reason
 		
-	def retract(self): reason = execute('rpm -e --nodeps '+self.rpmfile)
+	def retract(self): return execute('rpm -e --nodeps '+self.rpmfile)
 	
