@@ -1,6 +1,8 @@
 #
 #	Copyright Saul Youssef, June 2004
 #
+#       Modified, April 2006, S.Y.
+#
 from Environment import *
 from Execution   import *
 import os,time,CU,EnvironmentVariable
@@ -35,16 +37,16 @@ class ShellCommand(Environment):
 	def compatible(self,c): return Reason()
 	
 #-- Satisfiable
-	def satisfied(self):
-		r = Reason()
-		if ShellCommand._executed.has_key(self.signature): 
-			pass
-		else:
-			if self.getLastTry().ok(): 
-				r = Reason('Shell command ['+self.command+'] has not been successfully executed.')
-			else:                      
-				r = self.getLastTry()
-		return r
+	def satisfied(self): return Reason('Shell command ['+self.command+'] has not been aquired.',not self.acquired)
+#		r = Reason()
+#		if ShellCommand._executed.has_key(self.signature): 
+#			pass
+#		else:
+#			if not self.getLastTry().ok(): 
+#				r = Reason('Shell command ['+self.command+'] has not been successfully executed.')
+#			else:                      
+#				r = self.getLastTry()
+#		return r
 	def satisfiable(self): return Reason()
 	
 #-- Action
@@ -78,12 +80,13 @@ class ShellCommand(Environment):
 			if reason.ok(): reason,self.output = executeBase(self.command,self.mode)
 			if self.mode=='yes': print self.output
 		if reason.ok(): 
-			if ShellCommand._executed.has_key(self.signature): abort('Shell command ['+`self`+'] has already been executed.')
+			if ShellCommand._executed.has_key(self.signature) and 0: abort('Shell command ['+`self`+'] has already been executed.')
 			else: 
 				if len(self.signature)==3:
 					a,b,c = self.signature
 					self.signature = (a,b,c,os.getcwd(),CU.getCurrentUser(),)
 				ShellCommand._executed[self.signature] = 'executed'
+		self.lasttry = reason
 		return reason
 		
 	def retract(self): 
