@@ -46,12 +46,17 @@ class URLAccess(Access):
 		tmpdir = os.path.join(pac_anchor,pacmanDir,'tmp')
 		removeFile(os.path.join(tmpdir,name))
 			
-		if switch('wget'):
-			if verbo('down'):
-				status = os.system('cd '+tmpdir+'; wget '+os.path.join(self.url,name))
-				reason = Reason('Failure downloading ['+os.path.join(self.url,name)+'].',not status==0)
+#		if (switch('wget') or allow('wget')) and not allow('urllib2'):
+		if not allow('urllib2'):
+			tries = httpGetRetries()
+			if verbo('download'):
+				reason = execute('cd '+tmpdir+'; wget -q --tries='+`tries`+' '+os.path.join(self.url,name))
+#				status = os.system('cd '+tmpdir+'; wget '+os.path.join(self.url,name))
+				if not reason.ok(): 
+					print reason
+					reason = Reason('Failure downloading ['+os.path.join(self.url,name)+'].')
 			else:
-				reason = execute('cd '+tmpdir+'; wget '+os.path.join(self.url,name))
+				reason = execute('cd '+tmpdir+'; wget -q --tries='+`tries`+' '+os.path.join(self.url,name))
 		else:
 			reason = g.get(tmpdir)
 		if reason.ok(): 
