@@ -11,9 +11,13 @@ class UninstallShellCommand(ShellCommand):
 	action = 'uninstall shell'
 		
 	def satisfied(self): return Reason(`self`+' not installed yet.',not self.acquired)
-	def acquire(self):   return Reason()
+	def acquire(self): return Reason()
 	def retract(self):
 		reason = execute(self.command)
-		if reason.ok(): self.executed = 1
-		else: print 'WARNING: Uninstall shell command ['+self.command+'] has failed ['+`reason`+']...'
-		return Reason()
+		if reason.ok(): 
+			self.executed = 1
+			if not allow('uninstall-shell-stop'): reason = Reason()
+		else: 
+			self.executed = 1
+			print 'WARNING: Uninstall shell command ['+self.command+'] has failed ['+`reason`+'].  Ignoring...'
+		return reason
